@@ -48,7 +48,7 @@ brplus <- function(mdata,
                    ..., cores = getOption("utiml.cores", 1),
                    seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(mdata) != "mldr") {
+  if (!is(mdata, "mldr")) {
     stop("First argument must be an mldr object")
   }
   if (cores < 1) {
@@ -161,7 +161,7 @@ predict.BRPmodel <- function(object, newdata,
                              ..., cores = getOption("utiml.cores", 1),
                              seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(object) != "BRPmodel") {
+  if (!is(object, "BRPmodel")) {
     stop("First argument must be an BRPmodel object")
   }
 
