@@ -44,7 +44,7 @@ clr <- function(mdata,
                 cores = getOption("utiml.cores", 1),
                 seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(mdata) != "mldr") {
+  if (!is(mdata, "mldr")) {
     stop("First argument must be an mldr object")
   }
 
@@ -97,7 +97,7 @@ predict.CLRmodel <- function(object, newdata,
                             ..., cores = getOption("utiml.cores", 1),
                             seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(object) != "CLRmodel") {
+  if (!is(object, "CLRmodel")) {
     stop("First argument must be an CLRmodel object")
   }
 
