@@ -50,7 +50,7 @@ homer <- function (mdata,
                    iteration = 100, ..., cores = getOption("utiml.cores", 1),
                    seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(mdata) != "mldr") {
+  if (!is(mdata, "mldr")) {
     stop("First argument must be an mldr object")
   }
 
@@ -110,7 +110,7 @@ predict.HOMERmodel <- function (object, newdata,
                               ..., cores = getOption("utiml.cores", 1),
                               seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(object) != "HOMERmodel") {
+  if (!is(object, "HOMERmodel")) {
     stop("First argument must be a HOMERmodel object")
   }
 
