@@ -34,7 +34,7 @@ lp <- function (mdata,
                 cores = getOption("utiml.cores", 1),
                 seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(mdata) != "mldr") {
+  if (!is(mdata, "mldr")) {
     stop("First argument must be an mldr object")
   }
 
@@ -84,7 +84,7 @@ predict.LPmodel <- function(object, newdata,
                             ..., cores = getOption("utiml.cores", 1),
                             seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(object) != "LPmodel") {
+  if (!is(object, "LPmodel")) {
     stop("First argument must be a LPmodel object")
   }
 
