@@ -45,7 +45,7 @@ ppt <- function (mdata,
                  cores = getOption("utiml.cores", 1),
                  seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(mdata) != "mldr") {
+  if (!is(mdata, "mldr")) {
     stop("First argument must be an mldr object")
   }
 
@@ -138,7 +138,7 @@ predict.PPTmodel <- function(object, newdata,
                             ..., cores = getOption("utiml.cores", 1),
                             seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(object) != "PPTmodel") {
+  if (!is(object, "PPTmodel")) {
     stop("First argument must be a PPTmodel object")
   }
 
