@@ -52,7 +52,7 @@ rakel <- function (mdata,
                    ..., cores = getOption("utiml.cores", 1),
                    seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(mdata) != "mldr") {
+  if (!is(mdata, "mldr")) {
     stop("First argument must be an mldr object")
   }
 
@@ -134,7 +134,7 @@ predict.RAkELmodel <- function(object, newdata,
                             ..., cores = getOption("utiml.cores", 1),
                             seed = getOption("utiml.seed", NA)) {
   # Validations
-  if (class(object) != "RAkELmodel") {
+  if (!is(object, "RAkELmodel")) {
     stop("First argument must be a RAkELmodel object")
   }
 
